@@ -1,11 +1,11 @@
 #' @title Get Eurostat Codes
 #' @description Get definitions for Eurostat codes from Eurostat dictionaries.
-#' @details A character or a factor vector of codes returns a corresponding vector of definitions. \code{label_eurostat} labels also data.frames from \code{\link{get_eurostat}}. For vectors a dictionary name have to be supplied. For data.frames dictonary names are taken from column names. "time" and "values" columns are returned as they were, so you can supply data.frame from \code{\link{get_eurostat}} and get data.frame with definitions instead of codes.
-#' @param x A character or a factor vector or a data.frame. 
+#' @details A character or a factor vector of codes returns a corresponding vector of definitions. \code{label_eurostat} labels also data_frames from \code{\link{get_eurostat}}. For vectors a dictionary name have to be supplied. For data_frames dictonary names are taken from column names. "time" and "values" columns are returned as they were, so you can supply data_frame from \code{\link{get_eurostat}} and get data_frame with definitions instead of codes.
+#' @param x A character or a factor vector or a data_frame. 
 #' @param dic A string (vector) naming eurostat dictionary or dictionaries.
 #'  If \code{NULL} (default) dictionry names taken from column names of 
-#'  the data.frame.
-#' @param code For data.frames names of the column for which also code columns
+#'  the data_frame.
+#' @param code For data_frames names of the column for which also code columns
 #'   should be retained. The suffix "_code" is added to code column names.  
 #' @param eu_order Logical. Should Eurostat ordering used for label levels. 
 #'   Affects only factors.
@@ -13,7 +13,7 @@
 #'        "fr" and "de".
 #' @export
 #' @author Janne Huovari \email{janne.huovari@@ptt.fi}
-#' @return a vector or a data.frame.
+#' @return a vector or a data_frame.
 #' @examples
 #'  \dontrun{
 #'    lp <- get_eurostat("nama_aux_lp")
@@ -26,9 +26,9 @@
 #'  }
 label_eurostat <- function(x, dic = NULL, code = NULL, eu_order = FALSE, 
                            lang = "en"){
-  if (is.data.frame(x)){
+  if (is_tibble(x)){
     y <- x
-    for (i in names(y)[!(names(y) %in% c("time", "values"))]){
+    for (i in names(y)[!(names(y) %in% c("time", "values","flags"))]){
       y[[i]] <- label_eurostat(y[[i]], i, eu_order = eu_order, lang = lang)
     }
     
